@@ -20,7 +20,7 @@ $TreeView->columns(
                           class => "treeviewLink$size"
                          },
                          'Name'
-                     )
+                        )
                      . '&#160;',
                    $q->a(
                          {
@@ -28,7 +28,7 @@ $TreeView->columns(
                           class => "treeviewLink$size"
                          },
                          'Size'
-                     )
+                        )
                      . '&#160;',
                    $q->a(
                          {
@@ -36,7 +36,7 @@ $TreeView->columns(
                           class => "treeviewLink$size"
                          },
                          'Permission'
-                     )
+                        )
                      . '&#160;',
                    $q->a(
                          {
@@ -44,9 +44,9 @@ $TreeView->columns(
                           class => "treeviewLink$size"
                          },
                          'Last Modified'
-                     )
+                        )
                      . '&#160;'
-);
+                  );
 
 if (defined $q->param('byColumn')) {
     $TreeView->orderByColumn($q->param('byColumn'));
@@ -64,7 +64,7 @@ my $zoom = $q->div(
                           class => "treeviewLink$size"
                          },
                          '16'
-                     )
+                        )
                      . '&#160;|&#160;'
                      . $q->a(
                              {
@@ -72,7 +72,7 @@ my $zoom = $q->div(
                               class => "treeviewLink$size"
                              },
                              '22'
-                     )
+                            )
                      . '&#160;|&#160;'
                      . $q->a(
                              {
@@ -80,7 +80,7 @@ my $zoom = $q->div(
                               class => "treeviewLink$size"
                              },
                              '32'
-                     )
+                            )
                      . '&#160;|&#160;'
                      . $q->a(
                              {
@@ -88,7 +88,7 @@ my $zoom = $q->div(
                               class => "treeviewLink$size"
                              },
                              '48'
-                     )
+                            )
                      . '&#160;|&#160;'
                      . $q->a(
                              {
@@ -96,7 +96,7 @@ my $zoom = $q->div(
                               class => "treeviewLink$size"
                              },
                              '64'
-                     )
+                            )
                      . '&#160;|&#160;'
                      . $q->a(
                              {
@@ -104,7 +104,7 @@ my $zoom = $q->div(
                               class => "treeviewLink$size"
                              },
                              '128'
-                     )
+                            )
                      . '&#160;|&#160;'
                      . $q->a(
                              {
@@ -112,27 +112,26 @@ my $zoom = $q->div(
                               -class => "treeviewLink$size"
                              },
                              'simple'
-                     )
-);
+                            )
+                  );
 print($q->header,
       $q->start_html(
                      -title  => 'Columns',
                      -script => $TreeView->jscript() . $TreeView->preload(),
                      -style  => {-code => $TreeView->css()},
-      ),
+                    ),
       $q->div({align => 'center'}, $zoom . $q->br() . $TreeView->Tree(\@tree)),
       $q->end_html
-);
+     );
 
-sub recursiveReadDir
-{
+sub recursiveReadDir {
     my $dir = shift;
     chomp($dir);
     opendir(DIR, "$dir") or die ":$dir $!";
     my @files = readdir(DIR);
     closedir(DIR);
     my @t;
-    for (my $i = 0; $i <= $#files; $i++) {
+    for (my $i = 0 ; $i <= $#files ; $i++) {
         unless ($files[$i] =~ /^\./) {
             use File::stat;
             my $sb = stat($dir . $files[$i]);
@@ -140,7 +139,11 @@ sub recursiveReadDir
                 push @t,
                   {
                     text    => $files[$i],
-                    columns => [sprintf("%s", $sb->size), sprintf("%04o", $sb->mode & 07777), sprintf("%s", scalar localtime $sb->mtime)],
+                    columns => [
+                                sprintf("%s",   $sb->size),
+                                sprintf("%04o", $sb->mode & 07777),
+                                sprintf("%s",   scalar localtime $sb->mtime)
+                               ],
                   };
             } else {
                 my @st = recursiveReadDir("$dir$files[$i]/");
@@ -148,8 +151,13 @@ sub recursiveReadDir
                   {
                     text    => "$files[$i]",
                     subtree => [@st],
-                    href    => "./columns.pl?style=$style&amp;size=$size&amp;subfolder=$dir$files[$i]/",
-                    columns => [sprintf("%s", $sb->size), sprintf("%04o", $sb->mode & 07777), sprintf("%s", scalar localtime $sb->mtime)]
+                    href =>
+                      "./columns.pl?style=$style&amp;size=$size&amp;subfolder=$dir$files[$i]/",
+                    columns => [
+                                sprintf("%s",   $sb->size),
+                                sprintf("%04o", $sb->mode & 07777),
+                                sprintf("%s",   scalar localtime $sb->mtime)
+                               ]
                   };
             }
         }
