@@ -1,9 +1,11 @@
 #!/usr/bin/perl -w
 use lib qw(lib);
-use HTML::Menu::TreeView qw(Tree css jscript Style documentRoot size clasic preload);
+use HTML::Menu::TreeView qw(setClasic Tree css jscript Style documentRoot size clasic preload);
 use CGI qw(-compile :all  -private_tempfiles);
 use strict;
 my $htpath = documentRoot();
+setClasic() if param('setClasic');
+
 my $size = defined param('size') ? param('size') : 16;
 $size = ($size == 22 or $size == 32 or $size == 48 or $size == 64 or $size == 128) ? $size : 16;
 my @tree;
@@ -48,6 +50,15 @@ size($size);
 clasic(1) if (defined param('clasic'));
 my $zoom = div(
                {style => "font-size:$size" . "px;"},
+                a(
+                  {
+                   -href  => "./crystal.pl?style=Crystal&size=$size&setClasic=1",
+                   -class => "treeviewLink$size"
+                  },
+                  'setClasic'
+                 )
+                 . '&#160;|&#160;'
+                 .
                a(
                   {
                    -href  => './crystal.pl?style=Crystal&size=16',
