@@ -13,16 +13,16 @@ my $sort       = 0;
 my $pre        = undef;
 my $Changeroot = 1;
 my $result = GetOptions(
-  'module=s'   => \$mod,
-  'htdocs=s'   => \$htdocs,
-  'style=s'    => \$style,
-  'size=s'     => \$size,
-  'recursive|' => \$recursive,
-  'help|?'     => \$help,
-  'sort'       => \$sort,
-  'prefix=s'   => \$pre,
-  'store=s'    => \$outpath
-);
+                        'module=s'   => \$mod,
+                        'htdocs=s'   => \$htdocs,
+                        'style=s'    => \$style,
+                        'size=s'     => \$size,
+                        'recursive|' => \$recursive,
+                        'help|?'     => \$help,
+                        'sort'       => \$sort,
+                        'prefix=s'   => \$pre,
+                        'store=s'    => \$outpath
+                       );
 $help = 1 if ((not defined $mod) && (not defined $recursive));
 pod2usage(1) if $help;
 sortTree(1)  if $sort;
@@ -33,14 +33,15 @@ my %Paths;
 
 if ($recursive) {
     foreach my $key (@INC) {
-	if ( -d $key ) {
-#           my $key = "/var/www/html/admin/cgi-bin/lib/";
-	  $Changeroot  = 1;
-	  $root        = $key;
-	  @r           = split "", $root;
-	  $Paths{$key} = $key;
-	  push @modules, &recursive($key);
-	}
+        if (-d $key) {
+
+            #           my $key = "/var/www/html/admin/cgi-bin/lib/";
+            $Changeroot  = 1;
+            $root        = $key;
+            @r           = split "", $root;
+            $Paths{$key} = $key;
+            push @modules, &recursive($key);
+        }
     }
     documentRoot($htdocs);
     Style($style);
@@ -81,8 +82,7 @@ if ($recursive) {
     &module2treeview($mod, $mod, $pref);
 }
 
-sub module2treeview
-{
+sub module2treeview {
     my $module    = shift;
     my $modulname = shift;
     my $ddir      = shift;
@@ -113,13 +113,14 @@ sub module2treeview
               target  => 'rightFrame',
               subtree => [openTree($module, $infile, $module2html, $ddir),],
              },
-    );
-    if($recursive){
-      push @t ,{
-		text    => 'Index',
-		href    => "/index.html",
-		target  => '_parent',
-	      };
+            );
+    if ($recursive) {
+        push @t,
+          {
+            text   => 'Index',
+            href   => "/index.html",
+            target => '_parent',
+          };
     }
     documentRoot($htdocs);
     Style($style);
@@ -159,7 +160,8 @@ sub module2treeview
     close(OUT);
     my $fsrc = "$outpath/$ddir/$module" . '.html';
     open FRAME, ">$fsrc" or warn $!;
-    print FRAME qq(<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">
+    print FRAME
+      qq(<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">
 <html>
 <head>
 <title>$module</title>
@@ -174,29 +176,31 @@ sub module2treeview
     close(FRAME);
 }
 
-sub recursive
-{
+sub recursive {
     my $d = shift;
     my @DIR;
     chomp($d);
     opendir(IN, $d) or warn "$d $!:$/";
     my @files = readdir(IN);
     closedir(IN);
-    for (my $i = 0; $i <= $#files; $i++) {
+    for (my $i = 0 ; $i <= $#files ; $i++) {
         my $newFile = "$d/$files[$i]";
         unless ($files[$i] =~ /^\./) {
             my $prefix = "";
             my @fields = split "", $d;
-            for (my $j = 0; $j <= $#fields; $j++) {
+            for (my $j = 0 ; $j <= $#fields ; $j++) {
                 $prefix .= $fields[$j] if not defined $r[$j];
             }
             my $module2html = "$prefix/$files[$i]";
             $module2html =~ s/\.pm$//;
-            if (-d $newFile && ((not defined $Paths{$newFile})) && ($files[$i] ne 'auto') && !(is_empty($newFile))) {
+            if (   -d $newFile
+                && ((not defined $Paths{$newFile}))
+                && ($files[$i] ne 'auto')
+                && !(is_empty($newFile))) {
                 my $node = {
                             text    => $files[$i],
                             subtree => [&recursive($newFile)]
-                };
+                           };
                 $node->{href} = "$module2html.html" if (-e "$newFile.pm");
                 push @DIR, $node;
             } else {
@@ -210,8 +214,9 @@ sub recursive
                       {
                         text => $m,
                         href => "$module2html.html",
-                      } unless -d $m
-                          && !-e "$outpath/$module2html.html";
+                      }
+                      unless -d $m
+                      && !-e "$outpath/$module2html.html";
                 }
             }
         }
@@ -219,8 +224,7 @@ sub recursive
     return @DIR;
 }
 
-sub has_pod
-{
+sub has_pod {
     my $m = shift;
     use Fcntl qw(:flock);
     use Symbol;
@@ -236,8 +240,7 @@ sub has_pod
     return 0;
 }
 
-sub openTree
-{
+sub openTree {
     my ($module, $infile, $m2, $ddir) = @_;
     my @TREEVIEW;
     $module =~ s/\.pm$//;
@@ -252,17 +255,18 @@ sub openTree
     close $fh;
 
     for (@lines) {
-        if ($_ =~ /<h\d id="([^"]+)">(.+)<\/h\d>/){
+        if ($_ =~ /<h\d id="([^"]+)">(.+)<\/h\d>/) {
             my $href  = $1;
             my $title = $2;
             push @TREEVIEW,
-	    {
-	      text   => $title,
-	      href   => "$ddir/$module" . "frame.html#$href",
-	      target => 'rightFrame',
-	    };
+              {
+                text   => $title,
+                href   => "$ddir/$module" . "frame.html#$href",
+                target => 'rightFrame',
+              };
         }
-        $_ =~ s/<body([^>]+)>/<body $1 onload="if (parent.frames.length == 0){location.href = '$ddir\/$module.html';}">/;
+        $_ =~
+          s/<body([^>]+)>/<body $1 onload="if (parent.frames.length == 0){location.href = '$ddir\/$module.html';}">/;
         $_ =~ s/<a/<a target="_parent" /gi;
     }
     open OUT, ">$fsrc" or warn "$!: $fsrc";
@@ -271,8 +275,7 @@ sub openTree
     return @TREEVIEW;
 }
 
-sub is_empty
-{
+sub is_empty {
     my ($path) = @_;
     opendir DIR, $path;
     while (my $entry = readdir DIR) {
@@ -284,12 +287,11 @@ sub is_empty
     return 1;
 }
 
-sub recursiveMkDir
-{
+sub recursiveMkDir {
     my $d = shift;
     my @dirs = split "/", $d;
     my $x;
-    for (my $i = 0; $i <= $#dirs; $i++) {
+    for (my $i = 0 ; $i <= $#dirs ; $i++) {
         $x = '/' if $i == 0;
         $x .= $dirs[$i] . '/' if $dirs[$i];
         mkdir $x unless -d $x;
