@@ -7,19 +7,17 @@ my $q = new CGI;
 my @tree = (
             {
              text     => 'what',
-             style    => 'width:100px;',
-             addition => $q->checkbox(
+             addition => $q->div({align=>'right'},$q->div( {style=>'text-align:left;width:100px;'} ,$q->checkbox(
                                       -name  => 'what',
                                       -value => 'what',
-             ),
+             ))),
             },
             {
              text     => 'Whatever',
-             style    => 'width:100px;',
-             addition => $q->checkbox(
+             addition => $q->div({align=>'right'} ,$q->div( {style=>'text-align:left;width:100px;'} ,$q->checkbox(
                                       -name  => 'Whatever',
                                       -value => 'Whatever',
-             ),
+             )))
             }
 );
 my $TreeView = new HTML::Menu::TreeView();
