@@ -9,11 +9,11 @@ clasicPlusNode.src='/style/Crystal/22/html-menu-treeview/clasicPlusNode.gif';
 var clasicLastPlusNode = new Image(22,22);
 clasicLastPlusNode.src='/style/Crystal/22/html-menu-treeview/clasicLastPlusNode.gif';
 var folderGray = new Image(22,22);
-folderGray.src='/style/Crystal/22/html-menu-treeview/folderGray.gif';
+folderGray.src='/style/Crystal/22/html-menu-treeview/folder_grey.png';
 var folderGreen = new Image(22,22);
-folderGreen.src='/style/Crystal/22/html-menu-treeview/folderGreen.gif';
+folderGreen.src='/style/Crystal/22/html-menu-treeview/folder_green.png';
 var folderViolet = new Image(22,22);
-folderViolet.src='/style/Crystal/22/html-menu-treeview/folderViolet.gif';
+folderViolet.src='/style/Crystal/22/html-menu-treeview/folder_violet.png';
 var folderYellowClosed = new Image(22,22);
 folderYellowClosed.src='/style/Crystal/22/html-menu-treeview/folder_yellow.png';
 var folderOrangeClosed = new Image(22,22);
