@@ -1,13 +1,13 @@
+
 function displayTree(id){
-    if(document.getElementById(id)){
-        var e = document.getElementById(id);
-        var display = e.style.display;
-        if(display  ==  'none'){
-            e.style.display = '';
-        }else if(display  ==  ''){
-            e.style.display = 'none';
-        }
-    }
+  var e = document.getElementById(id);
+  if(!e)return;
+  var display = e.style.display;
+  if(display == "none"){
+	e.style.display = "";
+  }else if(display == ""){
+	e.style.display = "none";
+  }
 }
 var m_bOver = true;
 function ocNode(id,size){
@@ -57,7 +57,8 @@ function ocFolder(id){
 function hideArray(i){
     var first = 1;
     var display = '';
-    if(window.folders){
+    if(window.folders &&  window.folders[i]){
+      
         for (var j  =0;j < window.folders[i].length; j++){
             var node =document.getElementById('tr'+window.folders[i][j]);
             if(first){
@@ -96,4 +97,4 @@ function trUnder(id){
           if(node2)
           node2.className = '';
      }
-}
+}
\ No newline at end of file
